// Cheesy Screen Blanker
// ©1998 Bob Maple (bmaple@burner.com) - http://www.dimensional.com/~bobm/
// Do with me what you will


#include "stdio.h"
#include "stdlib.h"

#include <AppKit.h>
#include <InterfaceKit.h>


// Class definition

class CheesyBlank : public BApplication {

	public:
		
				CheesyBlank( uint32 blankSecs );
				~CheesyBlank();
		
		void	ReadyToRun();
		void	Pulse();

	
	private:

		BScreen		*scrInfo;
		BWindow		*blankWin;
		BView		*blankView;
		BRect		scrFrame;
		bool		isBlanked;
		uint32		blankInterval;
};


CheesyBlank :: CheesyBlank( uint32 blankSecs ) : BApplication( "application/x-bob-cheesyblanker" ) {

	isBlanked = FALSE;
	blankInterval = blankSecs;
}

CheesyBlank :: ~CheesyBlank() {
}

void CheesyBlank :: Pulse() {

		if( !isBlanked ) {	// Keep us from accidentally blanking twice, which _shouldn't_ be able
							// to happen anyway... ?
		
			if( idle_time() > (blankInterval * 1000000) ) {
				
				scrInfo = new BScreen();
				
				if( scrInfo->IsValid() ) {

					// We check this each time in case you've changed
					// workspace resolutions;  Size the window accordingly	

					scrFrame = scrInfo->Frame();
					delete	scrInfo;
		
					BPoint	sleepPos;
					BPoint	pollPos;
					uint32	junkInt;
				
					isBlanked = TRUE;
					SetPulseRate( 0.0 );

					HideCursor();
					blankWin->SetWorkspaces( B_CURRENT_WORKSPACE );
					blankWin->Show();
				
					blankWin->Lock();
					blankWin->ResizeTo( scrFrame.right, scrFrame.bottom );
					blankView->GetMouse( &sleepPos, &junkInt, FALSE );

					// Now we wait for some mouse input or something
				
					while( TRUE ) {
					
						blankView->GetMouse( &pollPos, &junkInt, FALSE );
					
						if( sleepPos != pollPos )
							break;
						else
							snooze( 250000 );	// Not really granular, but enough..
												// Afterall, it's CHEESYBLANKER!
					}
				
					blankWin->Unlock();
					blankWin->Hide();
					ShowCursor();
				
					SetPulseRate( 1000000 );
				
					isBlanked = FALSE;
				}
			}
		}
}
	


void CheesyBlank :: ReadyToRun() {

	scrInfo = new BScreen();
	
	if( scrInfo->IsValid() ) {
	
		scrFrame = scrInfo->Frame();
		delete	scrInfo;
		
		blankWin = new BWindow( scrFrame, "cheesy blanker", B_BORDERED_WINDOW, B_NOT_RESIZABLE );
		blankView= new BView( scrFrame, "cheesy view", B_FOLLOW_ALL, B_WILL_DRAW );
		
		blankView->SetViewColor( 0.0, 0.0, 0.0 );
		 blankWin->AddChild( blankView );
		
		SetPulseRate( 1000000 );  // Once a second, we'll be nice
	}
}



// Let the cheesiness begin

int main( int argc, char **argv ) {

	CheesyBlank		*Blanker;
	uint32			blankSecs = 300;	// Default 5 minutes
	
	printf( "CheesyBlanker v1.00\nby Bob Maple (bmaple@burner.com)\n" );
	
	if( argc < 2 )
		printf( "Defaulting to a 5 minute blank\n" );

	else
		blankSecs = atoi( argv[1] );
	
	Blanker = new CheesyBlank( blankSecs );
	Blanker->Run();
	
	delete Blanker;
	
	exit(0);
}
